============
 re6st-conf
============

-------------------------------
Configuration tool for re6stnet
-------------------------------

:Author: Nexedi
:Manual section: 1

SYNOPSIS
========

``re6st-conf`` ``--registry`` `url` [`options`...]

DESCRIPTION
===========

re6st-conf is a tool generating the files necessary to add a node to a re6st
network. It connects to the re6st registry to get a signed certificate with
an allocated IPv6 subnet.

USAGE
=====

Use ``re6st-conf --help`` to get the complete list of options.

SEE ALSO
========

``re6stnet``\ (8)
